;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "compiler-explorer" "20250928.1426"
  "Compiler explorer client (godbolt.org)."
  '((emacs "28.1")
    (plz   "0.9")
    (eldoc "1.15.0")
    (map   "3.3.1")
    (seq   "2.23"))
  :url "https://github.com/mkcms/compiler-explorer.el"
  :commit "9e32e10b13a53b1fbf5471c34e4c0ea7a5db9057"
  :revdesc "9e32e10b13a5"
  :keywords '("c" "tools")
  :authors '(("Michał Krzywkowski" . "k.michal@zoho.com"))
  :maintainers '(("Michał Krzywkowski" . "k.michal@zoho.com")))
